Crate locked_astroport_vault

Crate locked_astroport_vault 

Modules

claims
Contains the Claims struct for storing claims on locked LP tokens (UnlockingPositions).
contract
Contains the contract’s entrypoints.
error
Contains the contracts error type.
execute
Contains ExecuteMsg handler functions.
helpers
Contains helper and utility functions and traits.
migrations
Contains functions for migrating the contract state from older to newer versions.
msg
Contains the vaults API and related messages.
query
Contains QueryMsg handlers.
state
Contains structs and helpers for the state of the vault.